"""Models of the common app."""

# django imports
from django.db import models

# atlas imports
from .mix import *
from .species import *
from .cath import *
from .sequence import *
from .ec import *
from .structure import *
from .go import *
from .tree import *
from .documentation import *
from .entry import *
from .protein import *
from .active_site import *
from .molecule import *
from .residue import *
from .reaction import *
from .reference import *
from .mechanism import *
from .arrow import Arrow, ArrowRule
from .role import *
from .step import *
from .rule import Rule, StepRule, EntryRule


def get_unique_together_values(cls):
    """returns the unique together values in a way that can be used"""
    return cls.objects.values_list(*cls._meta.unique_together[0])


def get_choices(cls, field, fieldname):
    """Returns a choices list of tuples based on the values in the database"""
    return sorted(list(set(cls.objects.values_list(field, fieldname))))


# adds the get_unique_together_values to the default model
models.Model.get_unique_together_values = classmethod(get_unique_together_values)
models.Model.get_choices = classmethod(get_choices)
