# coding=utf-8
"""Includes the models related with the documentation"""

# django imports
from django.db import models
from django.utils.html import format_html

# atlas imports
from atlas import settings


class DocImage(models.Model):
    image = models.FileField(verbose_name="Image", blank=True, upload_to="doc_images/")
    title = models.CharField(max_length=1023, verbose_name="title", unique=True)
    legend = models.TextField(blank=True)

    def __str__(self):
        return self.title

    def html_img(self):
        return_html = '<img src="{0}/{1.image}" title="{1.title}">'.format(
            settings.MEDIA_URL, self)
        if self.legend:
            return_html += ('<span class="legend"><strong>Legend:'
                            '</strong>{0.legend}</span><br><br>'.format(self))
        return format_html(return_html)


class Doc(models.Model):
    DOC_CHOICES = (
        ("documentation", "Documentation"),
        ("documentation_functions", "Documentation Functions"),
        ("documentation_components", "Documentation Components"),
        ("homepage_description", "Homepage Description"),
        ("homepage_update", "Homepage Update"),
        ("about_description", "About Description"),
        ("footnote", "Footnote"),
        ("statistics", "Statistics"),
        ("curator_info", "Curator Info"),
        ("ezmechanism", "EzMechanism (Input Preparation)"),
        ("ezmechanism_output", "EzMechanism (Output Analysis)"),
    )
    type = models.CharField(max_length=1023, choices=DOC_CHOICES, verbose_name="type")
    title = models.CharField(max_length=1023, verbose_name="title")
    text = models.TextField(blank=True)
    numbering = models.CharField(default="", max_length=255, blank=True)

    class Meta:
        ordering = ("type", "numbering")

    def __str__(self):
        return "{0}: {1.numbering} - {1.title}".format(
            self.get_type_display(), self)
