"""Contains MixIn that add to all the models"""

# python core imports
import collections


class AtlasQuerySetMixIn(object):
    """Contains methods that can be shared by all models"""

    def counter(self, field):
        """Returns counter of the code field"""
        return collections.OrderedDict(collections.Counter(self.values_list(field, flat=True)).most_common())

    def counter_many(self, *fields):
        """Returns counter based on the fields provided"""
        return collections.Counter(self.values_list(*fields))

    def frequency(self, field, **kwargs):
        """Returns the frequency of all the values in the field column"""
        counter = self.counter(field)
        length = sum(counter.values())
        return {k: v/length for k, v in counter.items()}
